@@ -31,6 +31,11 @@ final readonly class StaticSelectFieldType extends AbstractFieldType
         return 'select';
     }
 
+    public function isSearchable(): false
+    {
+        return false;
+    }
+
     /**
      * @return SelectItem[]
      */
@@ -41,4 +46,10 @@ final readonly class StaticSelectFieldType extends AbstractFieldType
             $this->configuration['items']
         ) : [];
     }
+
+    public function isNullable(): false
+    {
+        return false;
+    }
+
 }
